#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-LTvK6AGSAhM9Py3hc2eCH4-attoparsec-internal

key:
    attoparsec-0.14.4-LTvK6AGSAhM9Py3hc2eCH4-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  79f86f7c76574934bf922aa998f40d56
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-LTvK6AGSAhM9Py3hc2eCH4-attoparsec-internal

depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-LdSSSJaqTWRKcmrPIp7yLP
key:                  attoparsec-0.14.4-LdSSSJaqTWRKcmrPIp7yLP
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  d8c4964e3a8701214f3e3d89998e4042
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-LdSSSJaqTWRKcmrPIp7yLP
depends:
    array-0.5.6.0
    attoparsec-0.14.4-LTvK6AGSAhM9Py3hc2eCH4-attoparsec-internal
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0 scientific-0.3.8.1-DiNCmJn3LCGK1KM9YeO7Hp
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

